@@ -12,11 +12,12 @@ insert_header = function(doc) {
 ## Makes latex header with macros required for highlighting, tikz and framed
 make_header_latex = function() {
   h = paste(c(
-    '\\usepackage{graphicx, color}', .header.maxwidth, opts_knit$get('header'),
+    sprintf('\\usepackage[%s]{graphicx}\\usepackage[%s]{color}',
+            opts_knit$get('latex.options.graphicx') %n% '',
+            opts_knit$get('latex.options.color') %n% ''),
+    .header.maxwidth, opts_knit$get('header'),
     if (getOption('OutDec') != '.') '\\usepackage{amsmath}',
-    if (out_format('latex')) {
-      if (opts_knit$get('use.highlight')) highlight_fun('boxes_latex')() else '\\usepackage{alltt}'
-    }
+    if (out_format('latex')) '\\usepackage{alltt}'
   ), collapse = '\n')
   if (opts_knit$get('self.contained')) h else {
     writeLines(h, 'knitr.sty')
@@ -36,11 +37,11 @@ insert_header_latex = function(doc, b) {
     i = i[1L]; l = str_locate(doc[i], b)
     tmp = str_sub(doc[i], l[, 1], l[, 2])
     str_sub(doc[i], l[,1], l[,2]) = str_c(tmp, make_header_latex())
-  } else if (parent_mode()) {
+  } else if (parent_mode() && !child_mode()) {
     # in parent mode, we fill doc to be a complete document
     doc[1L] = str_c(c(getOption('tikzDocumentDeclaration'), make_header_latex(),
-                      .knitEnv$tikzPackages, "\\begin{document}", doc[1L]), collapse = '\n')
-    doc[length(doc)] = str_c(doc[length(doc)], "\\end{document}", sep = '\n')
+                      .knitEnv$tikzPackages, '\\begin{document}', doc[1L]), collapse = '\n')
+    doc[length(doc)] = paste(doc[length(doc)], '\\end{document}', sep = '\n')
   }
   doc
 }
@@ -48,7 +49,7 @@ insert_header_latex = function(doc, b) {
 make_header_html = function() {
   h = opts_knit$get('header')[['highlight']]
   if (opts_knit$get('self.contained')){
-    str_c('<style type="text/css">', h, '</style>', collapse = "\n")
+    str_c('<style type="text/css">', h, '</style>', collapse = '\n')
   } else {
     writeLines(h, 'knitr.css')
     '<link rel="stylesheet" href="knitr.css" type="text/css" />'
@@ -56,11 +57,11 @@ make_header_html = function() {
 }
 
 insert_header_html = function(doc, b) {
-  i = which(str_detect(doc, b))
+  i = grep(b, doc)
   if (length(i) == 1L) {
     l = str_locate(doc[i], b)
     tmp = str_sub(doc[i], l[, 1], l[, 2])
-    str_sub(doc[i], l[,1], l[,2]) = str_c(tmp, "\n", make_header_html())
+    str_sub(doc[i], l[,1], l[,2]) = str_c(tmp, '\n', make_header_html())
   }
   doc
 }
@@ -112,7 +113,7 @@ set_header = function(...) {
 .header.hi.tex = theme_to_header_latex(.default.sty)$highlight
 .knitr.sty = file.path(.inst.dir, 'misc', 'knitr.sty')
 .knitr.sty = .knitr.sty[file.exists(.knitr.sty)][1L]
-.header.framed = paste(readLines(.knitr.sty), collapse = "\n")
+.header.framed = paste(readLines(.knitr.sty), collapse = '\n')
 # CSS for html syntax highlighting
 .header.hi.html = theme_to_header_html(.default.sty)$highlight
 rm(list = c('.inst.dir', '.knitr.sty')) # do not need them any more
