@@ -150,12 +150,15 @@ hook_r2swf = function(x, options) {
 #' @export
 render_html = function() {
   knit_hooks$restore()
-  opts_chunk$set(dev = 'png') # default device is png in HTML and markdown
+  set_html_dev()
   opts_knit$set(out.format = 'html')
   ## use div with different classes
   html.hook = function(name) {
     force(name)
     function (x, options) {
+      if (name == 'source') {
+        x = paste(c(hilight_source(x, 'html', options), ''), collapse = '\n')
+      }
       sprintf('<div class="%s"><pre class="knitr %s">%s</pre></div>\n', name, tolower(options$engine), x)
     }
   }
